
import base_section

from runtest import conditions


class Network(base_section.BaseSection):

    name = "network"
    options = [
        'build_interval',
        'build_timeout',
        'catalog_type',
        'default_network',
        'dns_servers',
        'endpoint_type',
        'floating_network_name',
        'port_vnic_type',
        'project_network_cidr',
        'project_network_mask_bits',
        'project_network_v6_cidr',
        'project_network_v6_mask_bits',
        'project_networks_reachable',
        'public_network_id',
        'public_router_id',
        'region',
        'shared_physical_network',
    ]

    @property
    def build_interval(self):
        pass

    @property
    def build_timeout(self):
        pass

    @property
    def catalog_type(self):
        pass

    @property
    def default_network(self):
        pass

    @property
    def dns_servers(self):
        pass

    @property
    def endpoint_type(self):
        pass

    @property
    def floating_network_name(self):
        c = conditions.BaseRule('neutron.client.enabled', 'eq', True)
        networks_legacy = self.get_item_when_condition_match(
            'neutron.client.server.admin_identity.network', c) or {}
        networks = self.get_item_when_condition_match(
            'neutron.client.resources.v2.admin_identity.network', c) or {}
        networks.update(networks_legacy)
        for network_name, network in networks.items():
            if network.get('router_external') is True:
                return network_name

    @property
    def port_vnic_type(self):
        pass

    @property
    def project_network_cidr(self):
        contrail_enabled = conditions.BaseRule('*.opencontrail.control.enabled',
                                               'eq', True, multiple='any')
        if contrail_enabled.check(self.pillar):
            return '10.100.0.0/24'
        else:
            pass

    @property
    def project_network_mask_bits(self):
        pass

    @property
    def project_network_v6_cidr(self):
        contrail_enabled = conditions.BaseRule('*.opencontrail.control.enabled',
                                               'eq', True, multiple='any')
        if contrail_enabled.check(self.pillar):
            return '2003::/120'
        else:
            pass

    @property
    def project_network_v6_mask_bits(self):
        contrail_enabled = conditions.BaseRule('*.opencontrail.control.enabled',
                                               'eq', True, multiple='any')
        if contrail_enabled.check(self.pillar):
            return '124'
        else:
            pass

    @property
    def project_networks_reachable(self):
        pass

    @property
    def public_network_id(self):
        c = conditions.BaseRule(field='keystone.client.enabled', op='eq',
                                val=True)
        nodes = self.get_nodes_where_condition_match(c)
        runtest_enable = conditions.BaseRule('runtest.enabled', 'eq', True)
        network_name = self.get_item_when_condition_match(
            'runtest.tempest.convert_to_uuid.network.public_network_id',
            runtest_enable)

        if not network_name:
            return

        keystone_profile_admin = self.runtest_opts.get(
            'keystone_profile_admin',
            {}
        )
        resp = self.authenticated_openstack_module_call(
            nodes[0],
            'neutronng.list_networks',
            profile=keystone_profile_admin
        )[nodes[0]]
        try:
            res = resp['networks']
        except (ValueError, TypeError, KeyError):
            raise Exception("Could not get list of networks. Got the response:"
                            " {}".format(resp))
        networks = [n['id'] for n in res if n['name'] == network_name]

        if len(networks) != 1:
            raise Exception("Error getting networks: {}".format(networks))

        return networks[0]

    @property
    def public_router_id(self):
        pass

    @property
    def region(self):
        pass

    @property
    def shared_physical_network(self):
        pass
